@@ -75,6 +75,21 @@ from .mesh import (
     Rectangle,
     Cube,
 )
+from .constitution import (
+    NeoHooke,
+    LinearElastic,
+    ThreeFieldVariation,
+    LineChange,
+    AreaChange,
+    VolumeChange,
+    MatadiMaterial,
+)
+from .tools import (
+    newtonrhapson,
+    save,
+    topoints,
+    project,
+)
 
 __all__ = [
     "__version__",
