@@ -9,4 +9,6 @@ from ._kinematics import (
     VolumeChange,
 )
 
-from ._mixed import Mixed
+from ._mixed import ThreeFieldVariation
+
+from ._wrappers import MatadiMaterial
