@@ -31,6 +31,17 @@ from ._boundary import Boundary
 from ._tools import partition, apply
 
 
+def _get_field(field):
+    "Get Field or First field of FieldMixed."
+
+    if "mixed" in str(type(field)).lower():
+        f = field.fields[0]
+    else:
+        f = field
+
+    return f
+
+
 def symmetry(field, axes=(True, True, True), x=0, y=0, z=0, bounds=None):
     "Create symmetry boundary conditions."
 
@@ -69,10 +80,7 @@ def uniaxial(field, right=1, move=0.2, clamped=False):
     """Define boundaries for uniaxial loading on a quarter model (x > 0, y > 0,
     z > 0) with symmetries at x=0, y=0 and z=0."""
 
-    if "mixed" in str(type(field)).lower():
-        f = field.fields[0]
-    else:
-        f = field
+    f = _get_field(field)
 
     f1 = lambda x: np.isclose(x, right)
 
@@ -99,10 +107,7 @@ def biaxial(field, right=1, move=0.2, clamped=False):
     like shape instead where the clamped faces at fx=1 and fy=1 do not share
     mesh-points."""
 
-    if "mixed" in str(type(field)).lower():
-        f = field.fields[0]
-    else:
-        f = field
+    f = _get_field(field)
 
     f1 = lambda x: np.isclose(x, right)
 
@@ -127,10 +132,7 @@ def planar(field, right=1, move=0.2, clamped=False):
     """Define boundaries for biaxial loading on a quarter model (x > 0, y > 0,
     z > 0) with symmetries at x=0, y=0 and z=0."""
 
-    if "mixed" in str(type(field)).lower():
-        f = field.fields[0]
-    else:
-        f = field
+    f = _get_field(field)
 
     f1 = lambda x: np.isclose(x, right)
 
@@ -148,3 +150,29 @@ def planar(field, right=1, move=0.2, clamped=False):
     out = bounds, *part, ext0
 
     return out
+
+
+def shear(field, bottom=0, top=1, move=0.2, sym=True):
+    """Define boundaries for shear loading between two clamped plates. The
+    bottom plate remains fixed while the shear is applied at the top plate."""
+
+    f = _get_field(field)
+
+    f0 = lambda x: np.isclose(x, bottom)
+    f1 = lambda x: np.isclose(x, top)
+
+    if sym:
+        bounds = symmetry(f, axes=(False, False, True))
+    else:
+        bounds = {}
+
+    bounds["bottom"] = Boundary(f, fy=f0)
+    bounds["top"] = Boundary(f, fy=f1, skip=(1, 0, 0))
+    bounds["move"] = Boundary(f, fy=f1, skip=(0, 1, 1), value=move)
+
+    part = partition(field, bounds)
+    ext0 = apply(f, bounds, part[0])
+
+    out = bounds, *part, ext0
+
+    return out
