@@ -25,7 +25,8 @@ along with Felupe.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
-import quadpy
+import numpy as np
+from string import ascii_lowercase
 
 from . import Scheme
 
@@ -33,7 +34,7 @@ from . import Scheme
 class GaussLegendre(Scheme):
     "A n-dimensional Gauss-Legendre quadrature rule."
 
-    def __init__(self, order: int, dim: int):
+    def __init__(self, order: int, dim: int, permute: bool = True):
         """Arbitrary `order` Gauss-Legendre quadrature rule of `dim` 1, 2 or 3
         on the interval [-1, 1] as approximation of
 
@@ -44,23 +45,43 @@ class GaussLegendre(Scheme):
         """
         # integration point weights and coordinates
 
-        if dim == 3:
-            scheme = quadpy.c3.product(quadpy.c1.gauss_legendre(order + 1))
-
-        elif dim == 2:
-            scheme = quadpy.c2.product(quadpy.c1.gauss_legendre(order + 1))
-
-        elif dim == 1:
-            scheme = quadpy.c1.gauss_legendre(order + 1)
-            scheme.points = scheme.points.reshape(1, -1)
-
-        else:
+        if dim not in [1, 2, 3]:
             raise ValueError("Wrong dimension.")
 
-        if dim > 1:
-            weights = scheme.weights * 2 ** dim
+        x, w = np.polynomial.legendre.leggauss(1 + order)
 
-        else:
-            weights = scheme.weights
+        points = (
+            np.stack(np.meshgrid(*([x] * dim), indexing="ij"))[::-1].reshape(dim, -1).T
+        )
 
-        super().__init__(scheme.points.T, weights)
+        idx = list(ascii_lowercase)[:dim]
+        weights = np.einsum(", ".join(idx), *([w] * dim)).ravel()
+
+        if permute and order == 1 and dim == 2:
+            points = points[[0, 1, 3, 2]]
+            weights = weights[[0, 1, 3, 2]]
+
+        if permute and order == 1 and dim == 3:
+            points = points[[0, 1, 3, 2, 4, 5, 7, 6]]
+            weights = weights[[0, 1, 3, 2, 4, 5, 7, 6]]
+
+        if permute and order == 2 and dim == 3:
+            vertices = np.array([0, 2, 8, 6, 18, 20, 26, 24])
+            edges = np.array([1, 5, 7, 3, 19, 23, 25, 21, 9, 11, 17, 15])
+            faces = np.array([12, 14, 10, 16, 4, 22])
+            volume = np.array([13])
+
+            permute = np.concatenate((vertices, edges, faces, volume))
+
+            points = points[permute]
+            weights = weights[permute]
+
+        super().__init__(points, weights)
+
+    def inv(self):
+        "Return the inverse quadrature scheme."
+
+        points = self.points.copy()
+        points[self.points != 0] = 1 / points[self.points != 0]
+
+        return Scheme(points, self.weights)
