@@ -28,24 +28,25 @@ along with Felupe.  If not, see <http://www.gnu.org/licenses/>.
 import numpy as np
 import felupe as fe
 
+import pytest
+
 
 def pre():
 
-    m = fe.Cube(n=3)
-    e = fe.Hexahedron()
-    q = fe.GaussLegendre(1, 3)
-    r = fe.Region(m, e, q)
+    r = fe.RegionHexahedron(fe.Cube(n=3))
 
     u = fe.Field(r, dim=3)
     p = fe.Field(r)
     J = fe.Field(r, values=1)
 
-    return r, (u, p, J)
+    f = fe.FieldMixed((u, p, J))
+
+    return r, f, (u, p, J)
 
 
 def test_solve_check():
 
-    r, (u, p, J) = pre()
+    r, f, (u, p, J) = pre()
 
     W = fe.constitution.NeoHooke(1, 3)
 
@@ -95,20 +96,20 @@ def test_solve_check():
 
 def test_solve_mixed_check():
 
-    r, fields = pre()
+    r, f, fields = pre()
     u = fields[0]
 
     f = fe.FieldMixed(fields)
 
     F, p, J = f.extract()
 
-    W = fe.constitution.NeoHooke(1, 3)
-    W_mixed = fe.constitution.Mixed(W.gradient, W.hessian)
+    W = fe.NeoHooke(1, 3)
+    W_mixed = fe.ThreeFieldVariation(W)
 
     F = u.extract()
 
     bounds = fe.dof.symmetry(u)
-    dof0, dof1, unstack = fe.dof.partition(f, bounds)
+    dof0, dof1, offsets = fe.dof.partition(f, bounds)
 
     u0ext = fe.dof.apply(u, bounds, dof0)
 
@@ -118,7 +119,7 @@ def test_solve_mixed_check():
     b = L.assemble().toarray()[:, 0]
     A = a.assemble()
 
-    dx = fe.tools.solve(A, b, f, dof0, dof1, u0ext, unstack)
+    dx = fe.tools.solve(A, b, f, dof0, dof1, u0ext, offsets)
 
     assert dx[0].shape == u.values.ravel().shape
     assert dx[1].shape == fields[1].values.ravel().shape
@@ -127,25 +128,25 @@ def test_solve_mixed_check():
     fe.tools.check(dx, f, b, dof1, dof0, verbose=0)
     fe.tools.check(dx, f, b, dof1, dof0, verbose=1)
 
-    fe.tools.save(r, f, unstack=unstack)
-    fe.tools.save(r, f, r=b, unstack=unstack)
+    fe.tools.save(r, f, offsets=offsets)
+    fe.tools.save(r, f, r=b, offsets=offsets)
     fe.tools.save(
         r,
         f,
         r=b,
-        unstack=unstack,
+        offsets=offsets,
         F=F,
         gradient=W_mixed.gradient(F, p, J),
     )
 
-    force = fe.tools.force(u, b, bounds["symx"], unstack=unstack)
-    moment = fe.tools.moment(u, b, bounds["symx"], unstack=unstack)
+    force = fe.tools.force(u, b, bounds["symx"], offsets=offsets)
+    moment = fe.tools.moment(u, b, bounds["symx"], offsets=offsets)
 
     for a in [2, 3, 4, 5]:
         curve = fe.tools.curve(np.arange(a), np.ones(a) * force[0])
 
 
-def test_newton():
+def test_newton_simple():
     def fun(x):
         return (x - 3) ** 2
 
@@ -154,13 +155,84 @@ def test_newton():
 
     x0 = np.array([3.1])
 
-    res = fe.tools.newtonrhapson(fun, x0, jac)
+    res = fe.tools.newtonrhapson(
+        x0, fun, jac, solve=np.linalg.solve, maxiter=32, verbose=True, timing=False
+    )
+
+    res = fe.tools.newtonrhapson(
+        x0, fun, jac, solve=np.linalg.solve, maxiter=32, verbose=True, timing=True
+    )
 
     assert abs(res.fun) < 1e-6
     assert np.isclose(res.x, 3, rtol=1e-2)
 
+    with pytest.raises(ValueError):
+        res = fe.tools.newtonrhapson(
+            x0, fun, jac, solve=np.linalg.solve, maxiter=4, verbose=False
+        )
+
+    with pytest.raises(ValueError):
+        x0 = np.array([np.nan])
+        res = fe.tools.newtonrhapson(x0, fun, jac, solve=np.linalg.solve)
+
+
+def test_newton():
+
+    # create a hexahedron-region on a cube
+    region = fe.RegionHexahedron(fe.Cube(n=3))
+
+    # add a displacement field and apply a uniaxial elongation on the cube
+    displacement = fe.Field(region, dim=3)
+    boundaries, dof0, dof1, ext0 = fe.dof.uniaxial(displacement, move=0.2, clamped=True)
+
+    # define the constitutive material behavior
+    umat = fe.NeoHooke(mu=1.0, bulk=2.0)
+
+    # newton-rhapson procedure
+    res = fe.newtonrhapson(
+        displacement,
+        umat=umat,
+        dof1=dof1,
+        dof0=dof0,
+        ext0=ext0,
+        timing=True,
+        verbose=True,
+    )
+
+
+def test_newton_mixed():
+
+    # create a hexahedron-region on a cube
+    mesh = fe.Cube(n=3)
+    region = fe.RegionHexahedron(mesh)
+    region0 = fe.RegionConstantHexahedron(fe.mesh.convert(mesh, 0))
+
+    # add a displacement field and apply a uniaxial elongation on the cube
+    u = fe.Field(region, dim=3)
+    p = fe.Field(region0)
+    J = fe.Field(region0, values=1)
+    field = fe.FieldMixed((u, p, J))
+
+    boundaries, dof0, dof1, offsets, ext0 = fe.dof.uniaxial(
+        field, move=0.2, clamped=True
+    )
+
+    # deformation gradient
+    F = field.extract(grad=True, sym=False, add_identity=True)
+
+    # define the constitutive material behavior
+    nh = fe.NeoHooke(mu=1.0, bulk=2.0)
+    umat = fe.ThreeFieldVariation(nh)
+
+    # newton-rhapson procedure
+    res = fe.newtonrhapson(
+        x0=field, umat=umat, dof1=dof1, dof0=dof0, ext0=ext0, offsets=offsets
+    )
+
 
 if __name__ == "__main__":
     test_solve_check()
     test_solve_mixed_check()
+    test_newton_simple()
     test_newton()
+    test_newton_mixed()
